package com.sintecmedia.components.exceptions;

import javax.faces.component.UIComponent;
import javax.faces.render.Renderer;

/**
 * Exception that thrown when problem occurs in one of richFaces components 
 *  designed. In general it can happen in two places component class, that 
 *  represents component in JSF component tree, or renderer class, that 
 *  converts compnent to html and back.
 * 
 * @author Igor Grinfeld, RealCommerce
 *
 */
public interface RichComponentException extends ComponentException {
	
	/**
	 * 
	 * @return component where exception occured, or component class attached 
	 *  to renderer if this exception is thrown by renderer.
	 */
	public UIComponent getComponent();
	
	/**
	 * 
	 * @return the renderer, if this exception is thrown by renderer, or null 
	 *  if it thrown by component class. 
	 */
	public Renderer getRenderer();
	
	/**
	 * 
	 * @param component class that throw this exception should set component 
	 *  class it occured in, even it actually happens in renderer.
	 */
	public void setComponent( UIComponent component );
	
	/**
	 * 
	 * @param renderer if exception is thrown by rendere it should set this 
	 *  method, else it will be null.
	 */
	public void setRenderer( Renderer renderer );
}
